from cffi import FFI

ffibuilder = FFI()

ffibuilder.cdef(
    """
    uint64_t fnv0_64(void *data, size_t len);
    uint32_t fnv0_32(void *data, size_t len);
    uint64_t fnv1_64(void *data, size_t len);
    uint32_t fnv1_32(void *data, size_t len);
    uint64_t fnv1a_64(void *data, size_t len);
    uint32_t fnv1a_32(void *data, size_t len);
"""
)
ffibuilder.set_source(
    "fnv_c.ext._fnv",
    """
    #include <stdint.h>
    #include <string.h>

    uint64_t fnv0_64(void *data, size_t len);
    uint32_t fnv0_32(void *data, size_t len);
    uint64_t fnv1_64(void *data, size_t len);
    uint32_t fnv1_32(void *data, size_t len);
    uint64_t fnv1a_64(void *data, size_t len);
    uint32_t fnv1a_32(void *data, size_t len);
""",
    sources=["fnv_c/ext/fnv.c"],
)


if __name__ == "__main__":
    ffibuilder.compile(verbose=True)



from setuptools import find_packages, setup

VERSION = "0.1.5"

DESCRIPTION = "Python 3.7+ FNV (fnv0, fnv1, fnv1a) non-cryptographic hash library implemented in C through libffi"
with open("README.md") as f:
    LONG_DESCRIPTION = f.read()


setup(
    name="fnv-c",
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    url="https://github.com/botify-labs/fnv-c",
    author="Fabien MARTY",
    author_email="fabien.marty@botify.com",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: Implementation :: PyPy",
        "License :: OSI Approved :: MIT License",
    ],
    packages=find_packages(),
    install_requires=["cffi>=1.0.0"],
    setup_requires=["cffi>=1.0.0"],
    cffi_modules=["./fnv_c/ext/build.py:ffibuilder"],
)